@@ -26,11 +26,11 @@ import jinja2
 import netaddr
 from neutron.agent.linux import ip_lib
 from neutron.agent.linux import utils as agent_utils
-from neutron.common import rpc as n_rpc
 from neutron_lib.api import validators
 from neutron_lib import constants
 from neutron_lib import context
 from neutron_lib.plugins import utils as plugin_utils
+from neutron_lib import rpc as n_rpc
 from neutron_lib.utils import file as file_utils
 from oslo_concurrency import lockutils
 from oslo_config import cfg
@@ -279,13 +279,6 @@ class BaseSwanProcess(object):
             {'vpnservice': vpnservice,
              'state_path': self.conf.state_path})
 
-    def _get_rootwrap_config(self):
-        if 'neutron-rootwrap' in cfg.CONF.AGENT.root_helper:
-            rh_tokens = cfg.CONF.AGENT.root_helper.split(' ')
-            if len(rh_tokens) == 3 and os.path.exists(rh_tokens[2]):
-                return rh_tokens[2]
-        return None
-
     @abc.abstractmethod
     def get_status(self):
         pass
@@ -852,8 +845,7 @@ class IPsecDriver(device_drivers.DeviceDriver):
         # TODO(pcm): Use router object method to tell if DVR, when available
         if router.router['distributed']:
             return router.snat_namespace.name
-        else:
-            return router.ns_name
+        return router.ns_name
 
     def get_router_based_iptables_manager(self, router):
         """Returns router based iptables manager
@@ -871,8 +863,7 @@ class IPsecDriver(device_drivers.DeviceDriver):
         # TODO(pcm): Use router object method to tell if DVR, when available
         if router.router['distributed']:
             return router.snat_iptables_manager
-        else:
-            return router.iptables_manager
+        return router.iptables_manager
 
     def add_nat_rule(self, router_id, chain, rule, top=False):
         """Add nat rule in namespace.
